*****************
Example Notebooks
*****************

`rail_projects` comes with several notebooks that demonstrate how to use it to analyze data in a number of different ways.

Here we describe the various notebooks and suggest other ways in which you might study the data.


.. toctree::
   :maxdepth: 2
   :caption: Creating and using a RailProject

   examples/rail_project_example.ipynb
   

.. toctree::
   :maxdepth: 2
   :caption: Making a new flavor in a RailProject

   examples/rail_project_new_flavor.ipynb
   
   
.. toctree::
   :maxdepth: 2
   :caption: The rail project component library

   examples/rail_project_library.ipynb

   
.. toctree::
   :maxdepth: 2
   :caption: Making plots

   examples/rail_plotting_control.ipynb

 
